import { InjectionToken, Pipe, Injectable, Inject, NgModule } from '@angular/core';

const NAMESPACE_NAME = new InjectionToken('NAMESPACE_NAME');
const SEPARATOR_NAME = new InjectionToken('SEPARATOR_NAME');

class SelectorOptionalsModel {
    constructor(id, name) {
        this.id = id;
        this.name = name;
    }
}

class EnumsPipe {
    constructor(nameSpaceGlobal, separatorGlobal) {
        this.nameSpaceGlobal = nameSpaceGlobal;
        this.separatorGlobal = separatorGlobal;
    }
    transform(currentEnum, { dictName, nameSpace = '', ignored = [] }) {
        const currentNameSpace = nameSpace ? nameSpace : this.nameSpaceGlobal;
        const resultArray = [];
        if (currentEnum) {
            Object.keys(currentEnum)
                .filter((x) => Number.isNaN(parseInt(x, 10)))
                .map((key) => {
                if (!(ignored.find((field) => field === key))) {
                    resultArray.push(new SelectorOptionalsModel(currentEnum[key], `${currentNameSpace}${this.separatorGlobal}${dictName}.${key}`));
                }
            });
        }
        return resultArray;
    }
}
EnumsPipe.decorators = [
    { type: Pipe, args: [{
                name: 'enumList'
            },] },
    { type: Injectable }
];
EnumsPipe.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: [NAMESPACE_NAME,] }] },
    { type: String, decorators: [{ type: Inject, args: [SEPARATOR_NAME,] }] }
];

class EnumsKeyPipe {
    constructor(nameSpaceGlobal, separatorGlobal) {
        this.nameSpaceGlobal = nameSpaceGlobal;
        this.separatorGlobal = separatorGlobal;
    }
    transform(value, { dictName, currentEnum, nameSpace }) {
        const currentNameSpace = nameSpace ? nameSpace : this.nameSpaceGlobal;
        let resultKeyPath = '';
        let key = Object.keys(currentEnum).find(key => currentEnum[key] === value);
        if (currentEnum && key) {
            resultKeyPath = `${currentNameSpace}${this.separatorGlobal}${dictName}.${key}`;
        }
        return resultKeyPath;
    }
}
EnumsKeyPipe.decorators = [
    { type: Pipe, args: [{
                name: 'enumKey'
            },] },
    { type: Injectable }
];
EnumsKeyPipe.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: [NAMESPACE_NAME,] }] },
    { type: String, decorators: [{ type: Inject, args: [SEPARATOR_NAME,] }] }
];

class AngularEnumsListModule {
    static forRoot(namespace = null, separator = null) {
        return {
            ngModule: AngularEnumsListModule,
            providers: [
                {
                    provide: NAMESPACE_NAME,
                    useValue: namespace || 'enums'
                },
                {
                    provide: SEPARATOR_NAME,
                    useValue: separator || ':'
                }
            ]
        };
    }
}
AngularEnumsListModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    EnumsPipe,
                    EnumsKeyPipe
                ],
                exports: [
                    EnumsPipe,
                    EnumsKeyPipe
                ],
                providers: [
                    EnumsPipe,
                    EnumsKeyPipe
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { AngularEnumsListModule, EnumsKeyPipe, EnumsPipe, NAMESPACE_NAME, SEPARATOR_NAME, SelectorOptionalsModel };
//# sourceMappingURL=angular-enum-list.js.map
